@@ -40,9 +40,8 @@ static guint chunk_view_signals[LAST_SIGNAL] = { 0 };
 static void chunk_view_update_image(ChunkView *view, guint xs, guint xe);
 static void chunk_view_redraw_samples(ChunkView *cv, off_t start, off_t end);
 static gint calc_x(ChunkView *cv, off_t sample, off_t width);
-static void chunk_view_autoscroll(gpointer timesource, 
-				  GTimeVal *current_time,
-				  gpointer user_data);
+static int chunk_view_autoscroll(gpointer timesource, GTimeVal *current_time,
+				 gpointer user_data);
 
 static void chunk_view_changed(Document *d, gpointer user_data)
 {
@@ -207,7 +206,6 @@ static void chunk_view_update_image_main(ChunkView *cv, GdkDrawable *image,
 	  y = j/2 + i*j;	  
 	  gdk_draw_line(image,get_gc(BARS,wid),xs,y,xe,y);
      }
-     player_work();
      /* Drawing one pixel to the left of xs is a workaround. Some part of the
       * code seems to draw one pixel wrong to the left. */
      view_cache_draw_part(cv->cache, image, (xs==0)?0:xs-1, xe, h, 
@@ -326,7 +324,7 @@ static void draw_time_bars(ChunkView *view, GdkEventExpose *event,
 	       /* puts(buf); */
 	       pl = gtk_widget_create_pango_layout( widget, buf );
 	       pango_layout_get_pixel_size(pl, &i, NULL);
-	       gdk_draw_layout( widget->window, widget->style->black_gc,
+	       gdk_draw_layout( widget->window, widget->style->fg_gc[GTK_STATE_NORMAL],
 				j-i/2, widget->allocation.height-font_height,
 				pl);
 	       g_object_unref(G_OBJECT(pl));
@@ -664,8 +662,8 @@ static gint chunk_view_motion_notify(GtkWidget *widget, GdkEventMotion *event)
 
 #define FLOAT(x) ((gfloat)(x))
 
-static void chunk_view_autoscroll(gpointer timesource, GTimeVal *current_time,
-				  gpointer user_data)
+static int chunk_view_autoscroll(gpointer timesource, GTimeVal *current_time,
+				 gpointer user_data)
 {
      GTimeVal diff,new_time;
      gfloat smp;
@@ -675,7 +673,7 @@ static void chunk_view_autoscroll(gpointer timesource, GTimeVal *current_time,
 
      g_assert(timesource == NULL || timesource == autoscroll_source);
 
-     if (!autoscroll) return;
+     if (!autoscroll) return 0;
      timeval_subtract(&diff,current_time,&autoscroll_start);
 
      /* printf("diff: %d,%d\n",diff.tv_sec,diff.tv_usec); */
@@ -728,6 +726,7 @@ static void chunk_view_autoscroll(gpointer timesource, GTimeVal *current_time,
 	       mainloop_time_source_restart(autoscroll_source,&new_time);
      }
 
+     return 0;
 }
 
 static gint chunk_view_button_release(GtkWidget *widget, GdkEventButton *event)
