@@ -59,7 +59,8 @@ static void config_dialog_ok(GtkButton *button, gpointer user_data)
         intbox_check(cd->disk_threshold) ||
 	intbox_check(cd->view_quality) ||
 	intbox_check_limit(cd->recent_files,0,MAINWINDOW_RECENT_MAX,
-			   _("number of recent files")) )
+			   _("number of recent files")) ||
+	format_selector_check(cd->fallback_format))
         return;
     /* c = (gchar *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cd->sound_driver)->entry)); */
     c = sound_driver_id_from_index(combo_selected_index(cd->sound_driver));
@@ -316,10 +317,6 @@ static void colors_click(GtkButton *button, gpointer user_data)
      key = gtk_label_parse_uline(GTK_LABEL(GTK_BIN(d)->child),_("_OK"));
      gtk_widget_add_accelerator (d, "clicked", ag, key, GDK_MOD1_MASK,
 				 (GtkAccelFlags) 0);
-     gtk_widget_add_accelerator (d, "clicked", ag, GDK_KP_Enter, 0,
-				 (GtkAccelFlags) 0);
-     gtk_widget_add_accelerator (d, "clicked", ag, GDK_Return, 0, 
-				 (GtkAccelFlags) 0);
      gtk_signal_connect(GTK_OBJECT(d),"clicked",GTK_SIGNAL_FUNC(color_apply),
 			ctable);
      gtk_signal_connect(GTK_OBJECT(d),"clicked",GTK_SIGNAL_FUNC(save_colors),
@@ -330,6 +327,9 @@ static void colors_click(GtkButton *button, gpointer user_data)
      gtk_signal_connect_object(GTK_OBJECT(d),"clicked",
 			       GTK_SIGNAL_FUNC(g_free),(GtkObject *)ctable);
      gtk_container_add(GTK_CONTAINER(c),d);
+     GTK_WIDGET_SET_FLAGS(d,GTK_CAN_DEFAULT);
+     gtk_widget_grab_default(d);
+
      d = gtk_button_new_with_label("");
      key = gtk_label_parse_uline(GTK_LABEL(GTK_BIN(d)->child),_("_Cancel"));
      gtk_widget_add_accelerator (d, "clicked", ag, key, GDK_MOD1_MASK,
@@ -752,7 +752,7 @@ static void config_dialog_init(ConfigDialog *cd)
 				 inifile_get_gboolean("mainwinFront",TRUE));
 
 
-    w = format_selector_new(FALSE);
+    w = format_selector_new(TRUE);
     format_selector_set(FORMAT_SELECTOR(w),&player_fallback_format);
     cd->fallback_format = FORMAT_SELECTOR(w);
 
