@@ -62,7 +62,7 @@ static guint floatbox_signals[LAST_SIGNAL] = { 0 };
 static void floatbox_update_text(Floatbox *box)
 {
      char e[30];
-     g_snprintf(e,sizeof(e),"%.7g",box->val);
+     format_float(box->val, e, sizeof(e));
      gtk_entry_set_text(GTK_ENTRY(box),e);
 }
 
@@ -83,6 +83,20 @@ static void floatbox_activate(GtkEditable *editable)
      if (parent_class->activate) parent_class->activate(editable);
 }
 
+static gint floatbox_focus_out(GtkWidget *widget, GdkEventFocus *event)
+{
+     char *c,*d;
+     float f;
+     Floatbox *b = FLOATBOX(widget);
+     c=(char *)gtk_entry_get_text(GTK_ENTRY(widget));
+     f=strtod(c,&d);
+     if (*d==0 && b->adj!=NULL && f>=gtk_adjustment_get_lower(b->adj) &&
+	 f<=gtk_adjustment_get_upper(b->adj)) {
+	  gtk_adjustment_set_value(b->adj,f);
+     }
+     return GTK_WIDGET_CLASS(parent_class)->focus_out_event(widget,event);
+}
+
 static void floatbox_class_init(FloatboxClass *klass)
 {
      parent_class = gtk_type_class(gtk_entry_get_type());
@@ -92,6 +106,7 @@ static void floatbox_class_init(FloatboxClass *klass)
 #else
      GTK_EDITABLE_CLASS(klass)->activate = floatbox_activate;
 #endif
+     GTK_WIDGET_CLASS(klass)->focus_out_event = floatbox_focus_out;
      klass->numchange=NULL;
 
      floatbox_signals[NUMCHANGED_SIGNAL] = 
@@ -115,13 +130,11 @@ static void floatbox_init(Floatbox *fbox)
      gtk_widget_set_usize(GTK_WIDGET(fbox),req.width/3,req.height);
 #endif
      fbox->adj = NULL;
-     fbox->val = 1.0; /* To force update */
-     floatbox_set(fbox,0.0);
 }
 
-guint floatbox_get_type(void)
+GtkType floatbox_get_type(void)
 {
-     static guint id=0;
+     static GtkType id=0;
      if (!id) {
 	  GtkTypeInfo info = {
 	       "Floatbox",
@@ -137,7 +150,10 @@ guint floatbox_get_type(void)
 void floatbox_set(Floatbox *box, float val)
 {
      if (box->val == val) return;
-     if (box->adj != NULL) {
+     if (box->adj != NULL && 
+	 val >= gtk_adjustment_get_lower(box->adj) && 
+	 val <= gtk_adjustment_get_upper(box->adj)) {
+
 	  gtk_adjustment_set_value(box->adj, val);
 	  return;
      }
@@ -150,6 +166,7 @@ GtkWidget *floatbox_new(float val)
 {
      Floatbox *box;
      box=gtk_type_new(floatbox_get_type());
+     box->val = val-1.0; /* To force update */
      floatbox_set(box,val);
      return GTK_WIDGET(box);
 }
