@@ -107,6 +107,14 @@ void gtk_widget_set_has_window(GtkWidget *w, gboolean has_window)
 	  GTK_WIDGET_UNSET_FLAGS(w,GTK_NO_WINDOW);
 }
 
+void gtk_widget_set_can_focus(GtkWidget *w, gboolean can_focus)
+{
+     if (!can_focus)
+	  GTK_WIDGET_SET_FLAGS(w,GTK_CAN_FOCUS);
+     else
+	  GTK_WIDGET_UNSET_FLAGS(w,GTK_CAN_FOCUS);
+}
+
 #endif
 
 int main(int argc, char **argv)
@@ -202,7 +210,7 @@ int main(int argc, char **argv)
      autoplay_mark_flag = inifile_get_gboolean("autoPlayMark",FALSE);
      varispeed_reset_flag = inifile_get_gboolean("speedReset",FALSE);
      varispeed_smooth_flag = inifile_get_gboolean("speedSmooth",TRUE);
-     dataformat_get_from_inifile("playerFallback",FALSE,
+     dataformat_get_from_inifile("playerFallback",TRUE,
 				 &player_fallback_format);
      chunk_filter_use_floating_tempfiles = 
 	  inifile_get_gboolean("tempfilesFP",TRUE);
@@ -1174,3 +1182,15 @@ char *translate_strip(const char *s)
      } else
 	  return c;
 }
+
+void format_float(float f, char *r, int maxsz)
+{
+     gchar *c;
+     g_snprintf(r,maxsz,"%#.7g",f);
+     c = strchr(r,0);
+     c-=2;
+     while (c>=r && isdigit(c[0]) && c[1]=='0') {
+	  c[1] = 0;
+	  c--;
+     }     
+}
