@@ -180,8 +180,12 @@ static void procstart(StatusBar *bar, gpointer user_data)
      Mainwindow *w = MAINWINDOW(user_data);
      mainwindow_set_sensitive(w,FALSE);
      w->esc_pressed_flag = FALSE;
+#if GTK_MAJOR_VERSION > 1
+     gtk_window_present(GTK_WINDOW(w));
+#else
      if (GTK_WIDGET(w)->window)
 	  gdk_window_raise(GTK_WIDGET(w)->window);
+#endif
      gtk_grab_add(GTK_WIDGET(w));
 }
 
@@ -544,6 +548,9 @@ static gint mainwindow_keypress(GtkWidget *widget, GdkEventKey *event)
 		    document_set_cursor(w->doc,o);
 	       }
 	       return TRUE;
+	  case GDK_Tab:
+	       o = (w->doc->viewstart + w->doc->viewend) / 2;
+	       document_set_cursor(w->doc,o);
 	  }
      else 
 	  switch (event->keyval) {	       
@@ -576,7 +583,9 @@ static gint mainwindow_keypress(GtkWidget *widget, GdkEventKey *event)
 	  case GDK_period: edit_stop(NULL,widget); return TRUE;
 	  case GDK_slash: edit_playselection(NULL, widget); return TRUE;
 	  case GDK_space:
-	       if (playing_document == w->doc) 
+	       if ((event->state & GDK_SHIFT_MASK) != 0)
+		    do_play(w,0,w->doc->chunk->length,w->loopmode);
+	       else if (playing_document == w->doc) 
 		    document_stop(w->doc,w->bouncemode);
 	       else if (w->doc != NULL)
 		    do_play(w,w->doc->cursorpos,w->doc->chunk->length,
@@ -584,13 +593,19 @@ static gint mainwindow_keypress(GtkWidget *widget, GdkEventKey *event)
 	       return TRUE;	       
 	  case GDK_Left:
 	  case GDK_KP_Left:
-	       document_scroll(w->doc, 
-			       -(w->doc->viewend - w->doc->viewstart)/MAINWINDOW_SCROLL_DELTA_RATIO);
+	       if (playing_document==w->doc && w->doc->followmode)
+		    player_nudge(-0.5);
+	       else
+		    document_scroll(w->doc,
+				    -(w->doc->viewend - w->doc->viewstart)/MAINWINDOW_SCROLL_DELTA_RATIO);
 	       return TRUE;
 	  case GDK_Right:
 	  case GDK_KP_Right:
-	       document_scroll(w->doc,
-			       (w->doc->viewend - w->doc->viewstart)/MAINWINDOW_SCROLL_DELTA_RATIO);
+	       if (playing_document==w->doc && w->doc->followmode)
+		    player_nudge(+0.5);
+	       else
+		    document_scroll(w->doc,
+				    (w->doc->viewend - w->doc->viewstart)/MAINWINDOW_SCROLL_DELTA_RATIO);
 	       return TRUE;
 	  case GDK_parenleft:
 	       o = 3*w->doc->chunk->format.samplerate;
@@ -617,6 +632,23 @@ static gint mainwindow_keypress(GtkWidget *widget, GdkEventKey *event)
 	       else
 		    do_play(w,w->doc->selend-o,w->doc->selend,FALSE);
 	       return TRUE;		    
+	  case GDK_Home:
+	       document_set_view(w->doc,0,w->doc->viewend-w->doc->viewstart);
+	       if (playing_document != w->doc || w->doc->followmode)
+		    document_set_cursor(w->doc,0);
+	       return TRUE;
+	  case GDK_End:
+	       /* Stop playback to prevent cursor jumping back to start point */
+	       document_stop(w->doc,FALSE);
+	       document_scroll(w->doc,w->doc->chunk->length);
+	       if (playing_document != w->doc || w->doc->followmode)
+		    document_set_cursor(w->doc,w->doc->chunk->length);
+	       return TRUE;
+	  case GDK_Tab:
+	       document_scroll(w->doc,
+			       w->doc->cursorpos-
+			       (w->doc->viewend+w->doc->viewstart)/2);
+	       return TRUE;
 	  }
      return GTK_WIDGET_CLASS(parent_class)->key_press_event(widget,event);
 }
@@ -812,6 +844,7 @@ static void file_close(GtkMenuItem *menuitem, gpointer user_data)
 	  fix_title(w);
 	  set_sensitive(w->need_chunk_items,FALSE);
 	  set_sensitive(w->need_undo_items,FALSE);
+	  set_sensitive(w->need_selection_items,FALSE);
 	  list_object_remove(mainwindow_objects,w);
      } else {
 	  geometry_stack_push(GTK_WINDOW(w),NULL,&window_geometry_stack);
@@ -1282,12 +1315,37 @@ static void edit_playall(GtkMenuItem *menuitem, gpointer user_data)
      do_play(w,0,w->doc->chunk->length,w->loopmode);
 }
 
+static gchar *get_help_page_contents(int page)
+{
+     const char **c;
+     char *ts[128];
+     int i,j,k,l,x;
+     gchar *r;
+     c = help_page_contents[page];
+     l = 0;
+     for (i=0; c[i]!=NULL && i<128; i++) {
+	  ts[i] = gettext(c[i]);
+	  l += strlen(ts[i]);
+     }
+     r = g_malloc(l+1);
+     k = 0;
+     for (j=0; j<i; j++) {
+	  x = strlen(ts[j]);
+	  memcpy(r+k, ts[j], x);
+	  k += x;
+     }
+     r[k] = 0;
+     g_assert(k==l);
+     return r;
+}
+
 static void help_readme(GtkMenuItem *menuitem, gpointer user_data)
 {
      GtkAccelGroup* ag;
      GtkWidget *window,*table,*notebook,*frame,*label,*button,*box1,*box2;
      int i;
      GtkWidget *scrolledwindow1, *viewport1, *label2;
+     gchar *c;
 #if GTK_MAJOR_VERSION == 2
      Mainwindow *mw = MAINWINDOW(user_data);
      PangoFontDescription *pfd;
@@ -1333,7 +1391,9 @@ static void help_readme(GtkMenuItem *menuitem, gpointer user_data)
 	gtk_widget_show (viewport1);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow1), viewport1);
 
-	label2 = gtk_label_new (_(help_page_contents[i]));
+	c = get_help_page_contents(i);
+	label2 = gtk_label_new (c);
+	g_free(c);
 #if GTK_MAJOR_VERSION == 2
 if (i==HELP_PAGE_SHORTCUTS)	// Keyboard tab only
 {
@@ -1935,7 +1995,8 @@ static GtkWidget *create_menu(Mainwindow *w)
 	  "/Edit/Select all", "/Cursor", "/View", "/Play/Play from cursor",
 	  "/Play/Play all", "/Play/Stop", "/Effects", 
 	  "/Effects/Normalize",
-	  "/Effects/Effects dialog..."
+	  "/Effects/Effects dialog...",
+	  "/Edit/Select none"
      };
 
      gchar *need_selection_names[] = {
@@ -2043,6 +2104,9 @@ static GtkWidget *create_menu(Mainwindow *w)
      item = gtk_item_factory_get_item(item_factory,"/Play/Record...");
      gtk_widget_set_sensitive(item,input_supported());
 
+     item = gtk_item_factory_get_item(item_factory,"/Edit/Delete");
+     gtk_widget_add_accelerator(item, "activate", accel_group, GDK_Delete, 0, 0);
+
      return gtk_item_factory_get_widget(item_factory,"<main>");
 }
 
@@ -2218,7 +2282,7 @@ static GtkWidget *create_toolbar(Mainwindow *w)
      b = gtk_pixmap_new(p, bmp);
      r = gtk_toolbar_append_element(
 	  GTK_TOOLBAR(t),GTK_TOOLBAR_CHILD_TOGGLEBUTTON,NULL,NULL,
-	  _("Follow cursor while playing"),"X",b,
+	  _("Keep view and playback together"),"X",b,
 	  GTK_SIGNAL_FUNC(followmode_toggle),w);
      if ( inifile_get_gboolean("followMode",FALSE) ) {
 	  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(r), TRUE);
@@ -2622,9 +2686,9 @@ static void mainwindow_init(Mainwindow *obj)
 		       GDK_ACTION_COPY | GDK_ACTION_MOVE);
 }
 
-guint mainwindow_get_type(void)
+GtkType mainwindow_get_type(void)
 {
-static guint id=0;
+static GtkType id=0;
 if (!id) {
 	GtkTypeInfo info = {
 	     "Mainwindow",
